// *********************************************************************
// *                          RF scanner                               *
// *                         Demo example                              *
// *********************************************************************
//
// Intended for:
//   HW: - TR-72G + CK-USB-04x development kit
//
//   OS: - v4.06G
//
// Description:
//   - This example scanes RF channels in range from MIN_CHANNEL to MAX_CHANNEL
//     (see Channel map in IQRF OS User's Guide - Appendix 2)
//   - RSSI values are stored in bufferCOM
//   - Use IQRF IDE Terminal to watch RSSI values
//     (Enable decimal data displaying in Terminal Log window to watch direct RSSI values)
//   - Minimum recommended distance between the scanner and tested TR module is few meters.
//
// ---------------------------------------------------------------------
// Online IQRF OS Reference Guide: https://doc.iqrf.org/IQRF-OS-Reference-guide
//
// Copyright (c) IQRF Tech s.r.o.
//
// File:    RF_SCANNER.c
// Version: v3.00                                   Revision: 17/06/2021
//
// Revision history:
//   v3.00: 17/06/2021  First release for TR-7xG.
//
// *********************************************************************
// Default IQRF include (modify the path according to your setup)
#include "IQRF.h"

// *********************************************************************
#define MIN_CHANNEL             0
#define MAX_CHANNEL             61

// *********************************************************************
void APPLICATION()
{
uns8 i, val;

    enableSPI();
    setLEDR();
    waitDelay(50);                          // Startup indication
    stopLEDR();
    i = MIN_CHANNEL;
    
    while (1)
    {
        setRFchannel(i);
        checkRF(90);                // Parameter 90 is mandatory to be RSSI detection more accurate
        val = getRSSI();            // See getRSSI description in IQRF OS Reference Guide how to calculate value in dBm
        writeToRAM(bufferCOM + i, val);

        if (++i > MAX_CHANNEL)
        {
            startSPI(i);
            i = MIN_CHANNEL;
            while(getStatusSPI());  // Until the packet is picked-up
        }
    }
}

// *********************************************************************
